<a id="mypy-boto3-clouddirectory"></a>

# mypy-boto3-clouddirectory

[![PyPI - mypy-boto3-clouddirectory](https://img.shields.io/pypi/v/mypy-boto3-clouddirectory.svg?color=blue)](https://pypi.org/project/mypy-boto3-clouddirectory)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-clouddirectory.svg?color=blue)](https://pypi.org/project/mypy-boto3-clouddirectory)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-clouddirectory?color=blue)](https://pypistats.org/packages/mypy-boto3-clouddirectory)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.CloudDirectory 1.17.101](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/clouddirectory.html#CloudDirectory)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.20.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-clouddirectory docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_clouddirectory/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-clouddirectory](#mypy-boto3-clouddirectory)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `CloudDirectory` service.

```bash
python -m pip install boto3-stubs[clouddirectory]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[clouddirectory]` in your environment:
  `python -m pip install 'boto3-stubs[clouddirectory]'`

Both type checking and auto-complete should work for `CloudDirectory` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[clouddirectory]` in your environment:
  `python -m pip install 'boto3-stubs[clouddirectory]'`

Both type checking and auto-complete should work for `CloudDirectory` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[clouddirectory]` in your environment:
  `python -m pip install 'boto3-stubs[clouddirectory]'`
- Run `mypy` as usual

Type checking should work for `CloudDirectory` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[clouddirectory]` in your environment:
  `python -m pip install 'boto3-stubs[clouddirectory]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CloudDirectory` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`CloudDirectoryClient` provides annotations for
`boto3.client("clouddirectory")`.

```python
import boto3

from mypy_boto3_clouddirectory import CloudDirectoryClient

client: CloudDirectoryClient = boto3.client("clouddirectory")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CloudDirectoryClient = session.client("clouddirectory")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_clouddirectory.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_clouddirectory import CloudDirectoryClient
from mypy_boto3_clouddirectory.paginator import (
    ListAppliedSchemaArnsPaginator,
    ListAttachedIndicesPaginator,
    ListDevelopmentSchemaArnsPaginator,
    ListDirectoriesPaginator,
    ListFacetAttributesPaginator,
    ListFacetNamesPaginator,
    ListIncomingTypedLinksPaginator,
    ListIndexPaginator,
    ListManagedSchemaArnsPaginator,
    ListObjectAttributesPaginator,
    ListObjectParentPathsPaginator,
    ListObjectPoliciesPaginator,
    ListOutgoingTypedLinksPaginator,
    ListPolicyAttachmentsPaginator,
    ListPublishedSchemaArnsPaginator,
    ListTagsForResourcePaginator,
    ListTypedLinkFacetAttributesPaginator,
    ListTypedLinkFacetNamesPaginator,
    LookupPolicyPaginator,
)

client: CloudDirectoryClient = boto3.client("clouddirectory")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_applied_schema_arns_paginator: ListAppliedSchemaArnsPaginator = client.get_paginator("list_applied_schema_arns")
list_attached_indices_paginator: ListAttachedIndicesPaginator = client.get_paginator("list_attached_indices")
list_development_schema_arns_paginator: ListDevelopmentSchemaArnsPaginator = client.get_paginator("list_development_schema_arns")
list_directories_paginator: ListDirectoriesPaginator = client.get_paginator("list_directories")
list_facet_attributes_paginator: ListFacetAttributesPaginator = client.get_paginator("list_facet_attributes")
list_facet_names_paginator: ListFacetNamesPaginator = client.get_paginator("list_facet_names")
list_incoming_typed_links_paginator: ListIncomingTypedLinksPaginator = client.get_paginator("list_incoming_typed_links")
list_index_paginator: ListIndexPaginator = client.get_paginator("list_index")
list_managed_schema_arns_paginator: ListManagedSchemaArnsPaginator = client.get_paginator("list_managed_schema_arns")
list_object_attributes_paginator: ListObjectAttributesPaginator = client.get_paginator("list_object_attributes")
list_object_parent_paths_paginator: ListObjectParentPathsPaginator = client.get_paginator("list_object_parent_paths")
list_object_policies_paginator: ListObjectPoliciesPaginator = client.get_paginator("list_object_policies")
list_outgoing_typed_links_paginator: ListOutgoingTypedLinksPaginator = client.get_paginator("list_outgoing_typed_links")
list_policy_attachments_paginator: ListPolicyAttachmentsPaginator = client.get_paginator("list_policy_attachments")
list_published_schema_arns_paginator: ListPublishedSchemaArnsPaginator = client.get_paginator("list_published_schema_arns")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
list_typed_link_facet_attributes_paginator: ListTypedLinkFacetAttributesPaginator = client.get_paginator("list_typed_link_facet_attributes")
list_typed_link_facet_names_paginator: ListTypedLinkFacetNamesPaginator = client.get_paginator("list_typed_link_facet_names")
lookup_policy_paginator: LookupPolicyPaginator = client.get_paginator("lookup_policy")
```

<a id="literals"></a>

### Literals

`mypy_boto3_clouddirectory.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_clouddirectory.literals import (
    BatchReadExceptionTypeType,
    ConsistencyLevelType,
    DirectoryStateType,
    FacetAttributeTypeType,
    FacetStyleType,
    ListAppliedSchemaArnsPaginatorName,
    ListAttachedIndicesPaginatorName,
    ListDevelopmentSchemaArnsPaginatorName,
    ListDirectoriesPaginatorName,
    ListFacetAttributesPaginatorName,
    ListFacetNamesPaginatorName,
    ListIncomingTypedLinksPaginatorName,
    ListIndexPaginatorName,
    ListManagedSchemaArnsPaginatorName,
    ListObjectAttributesPaginatorName,
    ListObjectParentPathsPaginatorName,
    ListObjectPoliciesPaginatorName,
    ListOutgoingTypedLinksPaginatorName,
    ListPolicyAttachmentsPaginatorName,
    ListPublishedSchemaArnsPaginatorName,
    ListTagsForResourcePaginatorName,
    ListTypedLinkFacetAttributesPaginatorName,
    ListTypedLinkFacetNamesPaginatorName,
    LookupPolicyPaginatorName,
    ObjectTypeType,
    RangeModeType,
    RequiredAttributeBehaviorType,
    RuleTypeType,
    UpdateActionTypeType,
)

def check_value(value: BatchReadExceptionTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_clouddirectory.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_clouddirectory.type_defs import (
    AddFacetToObjectRequestTypeDef,
    ApplySchemaRequestTypeDef,
    ApplySchemaResponseResponseTypeDef,
    AttachObjectRequestTypeDef,
    AttachObjectResponseResponseTypeDef,
    AttachPolicyRequestTypeDef,
    AttachToIndexRequestTypeDef,
    AttachToIndexResponseResponseTypeDef,
    AttachTypedLinkRequestTypeDef,
    AttachTypedLinkResponseResponseTypeDef,
    AttributeKeyAndValueTypeDef,
    AttributeKeyTypeDef,
    AttributeNameAndValueTypeDef,
    BatchAddFacetToObjectTypeDef,
    BatchAttachObjectResponseTypeDef,
    BatchAttachObjectTypeDef,
    BatchAttachPolicyTypeDef,
    BatchAttachToIndexResponseTypeDef,
    BatchAttachToIndexTypeDef,
    BatchAttachTypedLinkResponseTypeDef,
    BatchAttachTypedLinkTypeDef,
    BatchCreateIndexResponseTypeDef,
    BatchCreateIndexTypeDef,
    BatchCreateObjectResponseTypeDef,
    BatchCreateObjectTypeDef,
    BatchDeleteObjectTypeDef,
    BatchDetachFromIndexResponseTypeDef,
    BatchDetachFromIndexTypeDef,
    BatchDetachObjectResponseTypeDef,
    BatchDetachObjectTypeDef,
    BatchDetachPolicyTypeDef,
    BatchDetachTypedLinkTypeDef,
    BatchGetLinkAttributesResponseTypeDef,
    BatchGetLinkAttributesTypeDef,
    BatchGetObjectAttributesResponseTypeDef,
    BatchGetObjectAttributesTypeDef,
    BatchGetObjectInformationResponseTypeDef,
    BatchGetObjectInformationTypeDef,
    BatchListAttachedIndicesResponseTypeDef,
    BatchListAttachedIndicesTypeDef,
    BatchListIncomingTypedLinksResponseTypeDef,
    BatchListIncomingTypedLinksTypeDef,
    BatchListIndexResponseTypeDef,
    BatchListIndexTypeDef,
    BatchListObjectAttributesResponseTypeDef,
    BatchListObjectAttributesTypeDef,
    BatchListObjectChildrenResponseTypeDef,
    BatchListObjectChildrenTypeDef,
    BatchListObjectParentPathsResponseTypeDef,
    BatchListObjectParentPathsTypeDef,
    BatchListObjectParentsResponseTypeDef,
    BatchListObjectParentsTypeDef,
    BatchListObjectPoliciesResponseTypeDef,
    BatchListObjectPoliciesTypeDef,
    BatchListOutgoingTypedLinksResponseTypeDef,
    BatchListOutgoingTypedLinksTypeDef,
    BatchListPolicyAttachmentsResponseTypeDef,
    BatchListPolicyAttachmentsTypeDef,
    BatchLookupPolicyResponseTypeDef,
    BatchLookupPolicyTypeDef,
    BatchReadExceptionTypeDef,
    BatchReadOperationResponseTypeDef,
    BatchReadOperationTypeDef,
    BatchReadRequestTypeDef,
    BatchReadResponseResponseTypeDef,
    BatchReadSuccessfulResponseTypeDef,
    BatchRemoveFacetFromObjectTypeDef,
    BatchUpdateLinkAttributesTypeDef,
    BatchUpdateObjectAttributesResponseTypeDef,
    BatchUpdateObjectAttributesTypeDef,
    BatchWriteOperationResponseTypeDef,
    BatchWriteOperationTypeDef,
    BatchWriteRequestTypeDef,
    BatchWriteResponseResponseTypeDef,
    CreateDirectoryRequestTypeDef,
    CreateDirectoryResponseResponseTypeDef,
    CreateFacetRequestTypeDef,
    CreateIndexRequestTypeDef,
    CreateIndexResponseResponseTypeDef,
    CreateObjectRequestTypeDef,
    CreateObjectResponseResponseTypeDef,
    CreateSchemaRequestTypeDef,
    CreateSchemaResponseResponseTypeDef,
    CreateTypedLinkFacetRequestTypeDef,
    DeleteDirectoryRequestTypeDef,
    DeleteDirectoryResponseResponseTypeDef,
    DeleteFacetRequestTypeDef,
    DeleteObjectRequestTypeDef,
    DeleteSchemaRequestTypeDef,
    DeleteSchemaResponseResponseTypeDef,
    DeleteTypedLinkFacetRequestTypeDef,
    DetachFromIndexRequestTypeDef,
    DetachFromIndexResponseResponseTypeDef,
    DetachObjectRequestTypeDef,
    DetachObjectResponseResponseTypeDef,
    DetachPolicyRequestTypeDef,
    DetachTypedLinkRequestTypeDef,
    DirectoryTypeDef,
    DisableDirectoryRequestTypeDef,
    DisableDirectoryResponseResponseTypeDef,
    EnableDirectoryRequestTypeDef,
    EnableDirectoryResponseResponseTypeDef,
    FacetAttributeDefinitionTypeDef,
    FacetAttributeReferenceTypeDef,
    FacetAttributeTypeDef,
    FacetAttributeUpdateTypeDef,
    FacetTypeDef,
    GetAppliedSchemaVersionRequestTypeDef,
    GetAppliedSchemaVersionResponseResponseTypeDef,
    GetDirectoryRequestTypeDef,
    GetDirectoryResponseResponseTypeDef,
    GetFacetRequestTypeDef,
    GetFacetResponseResponseTypeDef,
    GetLinkAttributesRequestTypeDef,
    GetLinkAttributesResponseResponseTypeDef,
    GetObjectAttributesRequestTypeDef,
    GetObjectAttributesResponseResponseTypeDef,
    GetObjectInformationRequestTypeDef,
    GetObjectInformationResponseResponseTypeDef,
    GetSchemaAsJsonRequestTypeDef,
    GetSchemaAsJsonResponseResponseTypeDef,
    GetTypedLinkFacetInformationRequestTypeDef,
    GetTypedLinkFacetInformationResponseResponseTypeDef,
    IndexAttachmentTypeDef,
    LinkAttributeActionTypeDef,
    LinkAttributeUpdateTypeDef,
    ListAppliedSchemaArnsRequestTypeDef,
    ListAppliedSchemaArnsResponseResponseTypeDef,
    ListAttachedIndicesRequestTypeDef,
    ListAttachedIndicesResponseResponseTypeDef,
    ListDevelopmentSchemaArnsRequestTypeDef,
    ListDevelopmentSchemaArnsResponseResponseTypeDef,
    ListDirectoriesRequestTypeDef,
    ListDirectoriesResponseResponseTypeDef,
    ListFacetAttributesRequestTypeDef,
    ListFacetAttributesResponseResponseTypeDef,
    ListFacetNamesRequestTypeDef,
    ListFacetNamesResponseResponseTypeDef,
    ListIncomingTypedLinksRequestTypeDef,
    ListIncomingTypedLinksResponseResponseTypeDef,
    ListIndexRequestTypeDef,
    ListIndexResponseResponseTypeDef,
    ListManagedSchemaArnsRequestTypeDef,
    ListManagedSchemaArnsResponseResponseTypeDef,
    ListObjectAttributesRequestTypeDef,
    ListObjectAttributesResponseResponseTypeDef,
    ListObjectChildrenRequestTypeDef,
    ListObjectChildrenResponseResponseTypeDef,
    ListObjectParentPathsRequestTypeDef,
    ListObjectParentPathsResponseResponseTypeDef,
    ListObjectParentsRequestTypeDef,
    ListObjectParentsResponseResponseTypeDef,
    ListObjectPoliciesRequestTypeDef,
    ListObjectPoliciesResponseResponseTypeDef,
    ListOutgoingTypedLinksRequestTypeDef,
    ListOutgoingTypedLinksResponseResponseTypeDef,
    ListPolicyAttachmentsRequestTypeDef,
    ListPolicyAttachmentsResponseResponseTypeDef,
    ListPublishedSchemaArnsRequestTypeDef,
    ListPublishedSchemaArnsResponseResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseResponseTypeDef,
    ListTypedLinkFacetAttributesRequestTypeDef,
    ListTypedLinkFacetAttributesResponseResponseTypeDef,
    ListTypedLinkFacetNamesRequestTypeDef,
    ListTypedLinkFacetNamesResponseResponseTypeDef,
    LookupPolicyRequestTypeDef,
    LookupPolicyResponseResponseTypeDef,
    ObjectAttributeActionTypeDef,
    ObjectAttributeRangeTypeDef,
    ObjectAttributeUpdateTypeDef,
    ObjectIdentifierAndLinkNameTupleTypeDef,
    ObjectReferenceTypeDef,
    PaginatorConfigTypeDef,
    PathToObjectIdentifiersTypeDef,
    PolicyAttachmentTypeDef,
    PolicyToPathTypeDef,
    PublishSchemaRequestTypeDef,
    PublishSchemaResponseResponseTypeDef,
    PutSchemaFromJsonRequestTypeDef,
    PutSchemaFromJsonResponseResponseTypeDef,
    RemoveFacetFromObjectRequestTypeDef,
    ResponseMetadataTypeDef,
    RuleTypeDef,
    SchemaFacetTypeDef,
    TagResourceRequestTypeDef,
    TagTypeDef,
    TypedAttributeValueRangeTypeDef,
    TypedAttributeValueTypeDef,
    TypedLinkAttributeDefinitionTypeDef,
    TypedLinkAttributeRangeTypeDef,
    TypedLinkFacetAttributeUpdateTypeDef,
    TypedLinkFacetTypeDef,
    TypedLinkSchemaAndFacetNameTypeDef,
    TypedLinkSpecifierTypeDef,
    UntagResourceRequestTypeDef,
    UpdateFacetRequestTypeDef,
    UpdateLinkAttributesRequestTypeDef,
    UpdateObjectAttributesRequestTypeDef,
    UpdateObjectAttributesResponseResponseTypeDef,
    UpdateSchemaRequestTypeDef,
    UpdateSchemaResponseResponseTypeDef,
    UpdateTypedLinkFacetRequestTypeDef,
    UpgradeAppliedSchemaRequestTypeDef,
    UpgradeAppliedSchemaResponseResponseTypeDef,
    UpgradePublishedSchemaRequestTypeDef,
    UpgradePublishedSchemaResponseResponseTypeDef,
)

def get_structure() -> AddFacetToObjectRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-clouddirectory` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-clouddirectory docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_clouddirectory/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
